@@ -1,4 +1,4 @@
-use crate::memory::collect_memory;
+use crate::memory::*;
 
 use chrono::{DateTime, Utc};
 use log::*;
@@ -21,10 +21,11 @@ impl fmt::Debug for Measurement {
         let dt: DateTime<Utc> = self.timestamp.into();
         write!(
             fmt,
-            "Measurement {{ ts {}, cpu {:.3}, mem {:.3} }}",
+            "Measurement {{ ts {}, cpu {:.3}, mem {:.3}, maxmem {:.3} }}",
             dt.to_rfc3339(),
             self.cpu_utilization,
-            self.mem_utilization
+            self.mem_utilization,
+            self.max_mem_utilization
         )?;
         Ok(())
     }
@@ -103,6 +104,14 @@ pub fn aggregate(series: &[Measurement]) -> Option<Measurement> {
     })
 }
 
+/// Write generic system info into writer
+pub fn collect_info<W: std::fmt::Write>(f: &mut W, sys: &mut System) {
+    sys.refresh_cpu();
+    sys.refresh_memory();
+    collect_memory_info(f, sys);
+    writeln!(f, "Sysinfo: cpu count: {}", sys.processors().len()).unwrap();
+}
+
 /// Tests
 #[cfg(test)]
 mod tests {
